@@ -121,6 +121,7 @@ class ServiceNameCatalog:
         ServiceName("appstream", "AppStream"),
         ServiceName("appsync", "AppSync"),
         ServiceName("athena", "Athena"),
+        ServiceName("auditmanager", "AuditManager"),
         ServiceName("autoscaling-plans", "AutoScalingPlans"),
         ServiceName("autoscaling", "AutoScaling"),
         ServiceName("backup", "Backup"),
@@ -191,6 +192,7 @@ class ServiceNameCatalog:
         ServiceName("elastictranscoder", "ElasticTranscoder"),
         ServiceName("elb", "ElasticLoadBalancing"),
         ServiceName("elbv2", "ElasticLoadBalancingv2"),
+        ServiceName("emr-containers", "EMRContainers"),
         ServiceName("emr", "EMR"),
         ServiceName("es", "ElasticsearchService"),
         ServiceName("events", "EventBridge"),
@@ -208,6 +210,7 @@ class ServiceNameCatalog:
         ServiceName("groundstation", "GroundStation"),
         ServiceName("guardduty", "GuardDuty"),
         ServiceName("health", "Health"),
+        ServiceName("healthlake", "HealthLake"),
         ServiceName("honeycode", "Honeycode"),
         ServiceName("iam", "IAM"),
         ServiceName("identitystore", "IdentityStore"),
@@ -301,6 +304,7 @@ class ServiceNameCatalog:
         ServiceName("s3control", "S3Control"),
         ServiceName("s3outposts", "S3Outposts"),
         ServiceName("sagemaker-a2i-runtime", "AugmentedAIRuntime"),
+        ServiceName("sagemaker-edge", "SagemakerEdgeManager"),
         ServiceName("sagemaker-featurestore-runtime", "SagemakerFeatureStoreRuntime"),
         ServiceName("sagemaker-runtime", "SageMakerRuntime"),
         ServiceName("sagemaker", "SageMaker"),
